###################################################
### chunk number 1: loadLibrary
###################################################
library(SHARE)


###################################################
### chunk number 2: keremRand
###################################################
data(keremRand)
ls()


###################################################
### chunk number 3: genoSet
###################################################
unphasedGeno <- new("genoSet",
                    genoSeq = data.frame(keremRandAllele),
                    phenoData = data.frame(CF=keremRandStatus)
                    )
unphasedGeno


###################################################
### chunk number 4: unphasedHaplo
###################################################
unphasedHaplo <- haplo(unphasedGeno)
unphasedHaplo


###################################################
### chunk number 5: unphasedXV
###################################################
unphasedKerem <- list()
unphasedKerem[["Cross-Val"]] <- cshare(unphasedHaplo, status="CF",
                                       nfold=20, maxsnps=5, ModSelMethod="Cross-Val", Minherit="additive")
unphasedKerem[["Cross-Val"]]


###################################################
### chunk number 6: unphasedBIC
###################################################
unphasedKerem[["BIC"]] <- cshare(unphasedHaplo, , status="CF",
                         maxsnps=5, ModSelMethod="BIC", Minherit="additive", verbose=1)
unphasedKerem[["BIC"]]


###################################################
### chunk number 7: unphasedDPlotXV
###################################################
dplot(unphasedKerem[["Cross-Val"]])


###################################################
### chunk number 8: unphasedDPlotBIC
###################################################
dplot(unphasedKerem[["BIC"]])


###################################################
### chunk number 9: permu
###################################################
extdataDir <- system.file("extdata", package = "SHARE")
if("unphasedPermuPValue.RData" %in% dir(extdataDir)){
    load(file.path(extdataDir, "unphasedPermuPValue.RData"))
}else{
    unphasedPermuPValue <- shareTest(outObj=unphasedKerem[["Cross-Val"]],
                                     haploObj=unphasedHaplo,
                                     status="CF",
                                     nperm=1000 
                                     )
}
unphasedPermuPValue


###################################################
### chunk number 10: hapPool
###################################################
hapSeq <- apply(keremRandSeq, 1, 
		function(x){
			paste(x, sep="", collapse="-")
			}
		)

uniHap <- unique(hapSeq)
nHap <- length(uniHap)
hapNum <- unlist(sapply(1:nHap, 
                        function(x){
                            paste(paste(rep("0", ceiling(log10(nHap)) - nchar(as.character(x))), collapse=""), x, sep="", collapse="")
                        })
                 )
names(uniHap) <- paste("hap_", hapNum, sep="")

hapPool <- strsplit(uniHap, "-")
hapPool <- data.frame(t(data.frame(lapply(hapPool, function(x){as.numeric(x)}))))
colnames(hapPool) <- colnames(keremRandSeq)


###################################################
### chunk number 11: hapFreq
###################################################
hapCount <- sapply(uniHap, function(x){
		                       sum(x == hapSeq)
				       }
		  )

hapFreq <- hapCount / sum(hapCount)


###################################################
### chunk number 12: hapIndex
###################################################
noNameUniHap <- uniHap
names(noNameUniHap) <- NULL

hapIndex <- sapply(hapSeq, function(x){which(x == noNameUniHap)})
hap1Index <- hapIndex[c(1:length(hapIndex) %% 2) == 1]
hap2Index <- hapIndex[c(1:length(hapIndex) %% 2) == 0]


###################################################
### chunk number 13: widthOption
###################################################
options(width=60)


###################################################
### chunk number 14: phasedHaplo
###################################################
phasedHaplo <- new("haplo",
			haploSeq = hapPool,
			haploFreq = hapFreq,
			hap1 = hap1Index,
			hap2 = hap2Index,
			poolHapPair = as.character(1:length(hap1Index)),
			nPosHapPair = table(1:length(hap1Index)),
			post = rep(1, length(hap1Index)),
			pheno = data.frame(CF=keremRandStatus)
)


###################################################
### chunk number 15: widthOption
###################################################
options(width=80)


###################################################
### chunk number 16: sessionInfo
###################################################
sessionInfo()


